@@ -197,15 +197,24 @@ class TimeSpan:
         else:
             return NotImplemented
 
-    def __mul__(self, other: object) -> "TimeSpan":
-        if isinstance(other, int):
-            values = list(
-                map(lambda v: v * other, cast(list[Union[int, Fraction]], self.values))
-            )
-            return TimeSpan(values)
+    def __iadd__(self, other: object) -> "TimeSpan":
+        if isinstance(other, TimeSpan):
+            values = []
+            values.append(self.values)
+            values.append(other.values)
+            self.values = list(map(sum, zip(*values)))
+            return self
+        elif isinstance(other, timedelta):
+            vals = cast(list[Union[int, Fraction]], self.values)
+            vals[S] += int(other.total_seconds())
+            self.values = vals
+            return self
         else:
             return NotImplemented
 
+    def __radd__(self, other: timedelta) -> Union["TimeSpan", timedelta]:
+        return timedelta(seconds=other.total_seconds() + self.total_seconds())
+
     def __sub__(self, other: object) -> "TimeSpan":
         if isinstance(other, TimeSpan):
             values = []
@@ -221,14 +230,47 @@ class TimeSpan:
         else:
             return NotImplemented
 
-    def __radd__(self, other: timedelta) -> timedelta:
-        return timedelta(seconds=other.total_seconds() + self.total_seconds())
+    def __isub__(self, other: object) -> "TimeSpan":
+        if isinstance(other, TimeSpan):
+            values = []
+            values.append(self.values)
+            values.append(
+                list(map(lambda x: -x, cast(list[Union[int, Fraction]], other.values)))
+            )
+            self.values = list(map(sum, zip(*values)))
+            return self
+        elif isinstance(other, timedelta):
+            vals = cast(list[Union[int, Fraction]], self.values)
+            vals[S] -= int(other.total_seconds())
+            self.values = vals
+            return self
+        else:
+            return NotImplemented
 
     def __rsub__(self, other: Any) -> Any:
         if isinstance(other, timedelta):
             return timedelta(seconds=other.total_seconds() - self.total_seconds())
         return NotImplemented
 
+    def __mul__(self, other: object) -> "TimeSpan":
+        if isinstance(other, int):
+            values = list(
+                map(lambda v: v * other, cast(list[Union[int, Fraction]], self.values))
+            )
+            return TimeSpan(values)
+        else:
+            return NotImplemented
+
+    def __imul__(self, other: object) -> "TimeSpan":
+        if isinstance(other, int):
+            vals = list(
+                map(lambda v: v * other, cast(list[Union[int, Fraction]], self.values))
+            )
+            self.values = vals
+            return self
+        else:
+            return NotImplemented
+
     def __rmul__(self, other: object) -> "TimeSpan":
         if isinstance(other, int):
             values = list(
@@ -512,7 +554,7 @@ class TimeSpan:
                 self._seconds = int(args[0][5]) if len(args[0]) > 5 else 0
             else:
                 raise TimeSpanException(
-                    f"Positional argument 1 is of unexpectd type: {args[0].__class__.__name__}"
+                    f"Positional argument 1 is of unexpected type: {args[0].__class__.__name__}"
                 )
         elif len(args) > 6:
             raise TimeSpanException(
